==> libcommons-compress-java_1.13.orig.tar.xz: commons-compress-1.13-src/src/main/java/org/apache/commons/compress/compressors/snappy/FramedSnappyDialect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.compress.compressors.snappy;

/**
 * Dialects of the framing format that {@link FramedSnappyCompressorInputStream} can deal with.
 * @since 1.12
 */
public enum FramedSnappyDialect {
    /**
     * The standard as defined by the <a
     * href="https://github.com/google/snappy/blob/master/framing_format.txt">Snappy
     * framing format description</a>
     */
    STANDARD(true, true),
    /**
     * The format used by Apple's iWork Archives (.iwa files).
     */
    IWORK_ARCHIVE(false, false);

    private final boolean streamIdentifier, checksumWithCompressedChunks;

    private FramedSnappyDialect(final boolean hasStreamIdentifier,
                                final boolean usesChecksumWithCompressedChunks) {
        this.streamIdentifier = hasStreamIdentifier;
        this.checksumWithCompressedChunks = usesChecksumWithCompressedChunks;
    }

    boolean hasStreamIdentifier() {
        return streamIdentifier;
    }

    boolean usesChecksumWithCompressedChunks() {
        return checksumWithCompressedChunks;
    }
}

==> libcommons-compress-java_1.27.1.orig.tar.xz: commons-compress-1.27.1-src/src/main/java/org/apache/commons/compress/compressors/snappy/FramedSnappyDialect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.compress.compressors.snappy;

/**
 * Dialects of the framing format that {@link FramedSnappyCompressorInputStream} can deal with.
 *
 * @since 1.12
 */
public enum FramedSnappyDialect {
    /**
     * The standard as defined by the <a href="https://github.com/google/snappy/blob/master/framing_format.txt">Snappy framing format description</a>
     */
    STANDARD(true, true),
    /**
     * The format used by Apple's iWork Archives (.iwa files).
     */
    IWORK_ARCHIVE(false, false);

    private final boolean streamIdentifier, checksumWithCompressedChunks;

    FramedSnappyDialect(final boolean hasStreamIdentifier, final boolean usesChecksumWithCompressedChunks) {
        this.streamIdentifier = hasStreamIdentifier;
        this.checksumWithCompressedChunks = usesChecksumWithCompressedChunks;
    }

    boolean hasStreamIdentifier() {
        return streamIdentifier;
    }

    boolean usesChecksumWithCompressedChunks() {
        return checksumWithCompressedChunks;
    }
}
